==> ejc-outcontract-api-3.0.0-20220107.014412-4-sources.jar: com/ejianc/foundation/outcontract/vo/OutcontractMaterialVO.java <==
package com.ejianc.foundation.outcontract.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资（周转材）合同价
 * 
 * @author generator
 * 
 */
public class OutcontractMaterialVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long outcontractId; // 合同id
    private Long materialId; // 物资id
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryName; // 物资分类名称
    private String materialCode; // 物资编码
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private String materialUnit; // 计量单位
    private String strengthGrade; // 强度等级
    private String brandTrademark; // 品牌商标
    private BigDecimal quantity; // 暂定数量
    private BigDecimal untaxUnitPrice; // 不含税单价
    private BigDecimal taxRate; // 税率（%）
    private BigDecimal taxUnitPrice; // 含税单价
    private BigDecimal totalPrice; // 合价
    private BigDecimal leaseTerm; // 租赁期（天）
    private String remark; // 备注
    

    public Long getOutcontractId() {
        return outcontractId;
    }

    public void setOutcontractId(Long outcontractId) {
        this.outcontractId = outcontractId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public String getStrengthGrade() {
        return strengthGrade;
    }

    public void setStrengthGrade(String strengthGrade) {
        this.strengthGrade = strengthGrade;
    }
    public String getBrandTrademark() {
        return brandTrademark;
    }

    public void setBrandTrademark(String brandTrademark) {
        this.brandTrademark = brandTrademark;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getUntaxUnitPrice() {
        return untaxUnitPrice;
    }

    public void setUntaxUnitPrice(BigDecimal untaxUnitPrice) {
        this.untaxUnitPrice = untaxUnitPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    public void setTaxUnitPrice(BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public BigDecimal getLeaseTerm() {
        return leaseTerm;
    }

    public void setLeaseTerm(BigDecimal leaseTerm) {
        this.leaseTerm = leaseTerm;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-outcontract-api-3.0.0-20220429.023913-76-sources.jar: com/ejianc/foundation/outcontract/vo/OutcontractMaterialVO.java <==
package com.ejianc.foundation.outcontract.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资（周转材）合同价
 * 
 * @author generator
 * 
 */
public class OutcontractMaterialVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long outcontractId; // 合同id
    private Long materialId; // 物资id
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryName; // 物资分类名称
    private String materialCode; // 物资编码
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private String materialUnit; // 计量单位
    private String strengthGrade; // 强度等级
    private String brandTrademark; // 品牌商标
    private BigDecimal quantity; // 暂定数量
    private BigDecimal untaxUnitPrice; // 不含税单价
    private BigDecimal taxRate; // 税率（%）
    private BigDecimal taxUnitPrice; // 含税单价
    private BigDecimal totalPrice; // 合价
    private BigDecimal leaseTerm; // 租赁期（天）
    private String remark; // 备注
    
    private String errorMsg; // 导入错误信息
    

    public Long getOutcontractId() {
        return outcontractId;
    }

    public void setOutcontractId(Long outcontractId) {
        this.outcontractId = outcontractId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public String getStrengthGrade() {
        return strengthGrade;
    }

    public void setStrengthGrade(String strengthGrade) {
        this.strengthGrade = strengthGrade;
    }
    public String getBrandTrademark() {
        return brandTrademark;
    }

    public void setBrandTrademark(String brandTrademark) {
        this.brandTrademark = brandTrademark;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getUntaxUnitPrice() {
        return untaxUnitPrice;
    }

    public void setUntaxUnitPrice(BigDecimal untaxUnitPrice) {
        this.untaxUnitPrice = untaxUnitPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    public void setTaxUnitPrice(BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public BigDecimal getLeaseTerm() {
        return leaseTerm;
    }

    public void setLeaseTerm(BigDecimal leaseTerm) {
        this.leaseTerm = leaseTerm;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public String getErrorMsg() {
		return errorMsg;
	}

	public void setErrorMsg(String errorMsg) {
		this.errorMsg = errorMsg;
	}
    
}
